@@ -11,7 +11,7 @@ class Translatable(object):
 
     @hybrid_property
     def current_translation(self):
-        locale = str(self.__translatable__['locale_getter']())
+        locale = str(self.__locale_getter__())
         if locale in self.translations:
             try:
                 self._current_translation = self.translations[locale]
@@ -30,7 +30,7 @@ class Translatable(object):
 
     @current_translation.setter
     def current_translation(self, obj):
-        locale = str(self.__translatable__['locale_getter']())
+        locale = str(self.__locale_getter__())
         obj.locale = locale
         self.translations[locale] = obj
 
@@ -44,7 +44,7 @@ class Translatable(object):
 
     @classmethod
     def load_lazy_relationships(cls):
-        locale = str(cls.__translatable__['locale_getter']())
+        locale = str(cls.__locale_getter__.im_func(cls))
         translation_cls = cls.__translatable__['class']
         cls._current_translation = sa.orm.relationship(
             translation_cls,
