@@ -12,9 +12,9 @@ class TestJoinedTableInheritance(TestCase):
                 sa.Column('name', sa.Unicode(255)),
                 sa.Column('content', sa.UnicodeText)
             ]
+            __locale_getter__ = lambda cls: 'en'
             __translatable__ = {
                 'base_classes': (self.Model, ),
-                'locale_getter': lambda: 'en'
             }
 
             id = sa.Column(sa.Integer, autoincrement=True, primary_key=True)
